/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.puk.param.hierarchie;

import de.bsvrz.puk.param.param.Parametrierung;

/**
 * Der Manager für den Zugriff auf die Objekthierarchie innerhalb der
 * Parametrierung.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ParametrierungsHierarchieManager {

	/** die in der Konfiguration definierte Typ-Hierarchie. */
	private final TypHierarchie typHierarchie;

	/**
	 * die Hierarchie, der aus der Typhierarchie ermittelten Objekthierarchie.
	 */
	private final ObjektHierarchie objektHierarchie = new ObjektHierarchie();

	/**
	 * Konstruktor, erzeugt eine Instanz des Hierarchiemanagers.
	 *
	 * @param parametrierung
	 *            das verwendete Parametrierungsmodul
	 */
	public ParametrierungsHierarchieManager(final Parametrierung parametrierung) {
		typHierarchie = new TypHierarchie(parametrierung.getVerbindung());
		objektHierarchie.rebuild(typHierarchie);
	}

	/**
	 * aktualisiert die in der Objekthierarchie enthaltenen Objekte.
	 */
	public void aktualisiereObjekte() {
		objektHierarchie.rebuild(typHierarchie);
	}

	/**
	 * liefert das Hierarchieobjekt, welches das SystemObject mit der gegebenen
	 * ID repräsentiert.
	 *
	 * @param id
	 *            die ID
	 * @return das Hierarchieobjekt oder <i>null</i>, wenn keines gefunden wurde
	 */
	public HierarchieObjekt getHierarchieObjekt(final long id) {
		return objektHierarchie.getHierarchieObjekt(id);
	}
}
